## S3 method for class 'fitsad':
coefficients(object, ...)## S3 method for class 'fitrad':
coefficients(object, ...)
## S3 method for class 'fitsad':
fitted.values(object, ...)
## S3 method for class 'fitrad':
fitted.values(object, ...)
## S3 method for class 'fitsad':
fitted(object, ...)
## S3 method for class 'fitrad':
fitted(object, ...)
## S3 method for class 'fitsad':
residuals(object, ...)
## S3 method for class 'fitrad':
residuals(object, ...)
fitsad
and fitrad objects using the generic methods defined in the "stats" package.
Please see the original man pages for each method.coefficients is an alias to coef (implemented in package "bbmle").
fitted and fitted.values provide an alternative interface to radpred;
these are also used to calcutate residuals.
Notice that radpred is a preferred interface for most calculations, specially if there are several ties.